colour.plotting.models Module — Colour 0.3.0 documentation

# colour.plotting.models Module

## Colour Models Plotting

Defines the colour models plotting objects:

- `colourspaces_CIE_1931_chromaticity_diagram_plot()`
- `single_transfer_function_plot()`
- `multi_transfer_function_plot()`

`colour.plotting.models.` `get_RGB_colourspace`(colourspace)

  Returns the RGB colourspace with given name.

  Parameters: | colourspace (Unicode) – RGB Colourspace name.
  Returns: | RGB Colourspace.
  Return type: | RGB_Colourspace
  Raises: | `KeyError` – If the given colourspace is not found in the factory colourspaces.

`colour.plotting.models.` `colourspaces_CIE_1931_chromaticity_diagram_plot`(*args, **kwargs)

  Plots given colourspaces in CIE 1931 Chromaticity Diagram.

  Parameters: | colourspaces (list, optional) – Colourspaces to plot. cmfs (unicode, optional) – Standard observer colour matching functions used for diagram bounds. **kwargs (**) – Keywords arguments.
  Returns: | Definition success.
  Return type: | bool

  Examples

      >>> csps = ['sRGB', 'ACES RGB']
      >>> colourspaces_CIE_1931_chromaticity_diagram_plot(csps)
      True

`colour.plotting.models.` `single_transfer_function_plot`(colourspace='sRGB', **kwargs)

  Plots given colourspace transfer function.

  Parameters: | colourspace (unicode, optional) – RGB Colourspace transfer function to plot. **kwargs (**) – Keywords arguments.
  Returns: | Definition success.
  Return type: | bool

  Examples

      >>> single_transfer_function_plot()
      True

`colour.plotting.models.` `multi_transfer_function_plot`(*args, **kwargs)

  Plots given colourspaces transfer functions.

  Parameters: | colourspaces (list, optional) – Colourspaces transfer functions to plot. inverse (bool) – Plot inverse transfer functions. **kwargs (**) – Keywords arguments.
  Returns: | Definition success.
  Return type: | bool

  Examples

      >>> multi_transfer_function_plot(['sRGB', 'Rec. 709'])
      True